use clap::Parser;

/// TOTP - One Time Password generator
#[derive(Parser, Debug)]
#[clap(author, version, about, long_about = None)]
struct Args {
    /// The secret to use
    #[clap(short, long)]
    secret: String,

    /// Interval between two numbers generation
    #[clap(short, long, default_value_t = 30)]
    topt_step: u64,

    /// Size of generated secret
    #[clap(short, long, default_value_t = 6)]
    len: u32,
}

fn main() {
    let args: Args = Args::parse();

    let number = libotp::totp(
        &args.secret.to_ascii_uppercase(),
        args.len,
        args.topt_step,
        0,
    );

    println!("Secret len = {}", number.unwrap());
}
